@@ -1,5 +1,5 @@
 import requests
-from crypt import encrypt, decrypt
+from .crypt import encrypt, decrypt
 import json
 
 key = None
